acdecom - Acoustic Wave Decomposition in Flow Ducts.
===================================================


Documentation
-------------

The [documentation](www.documentation.de) provides information for the following:

- Mehtods and Parameters
- Theory and Usage
- Examples and Validation.

Installation
------------

Use ``pip`` to install these utilities

    pip install acdecom


Contributing
------------

If you want to contribute with
- Code development
- Bugfixes
- Examples or validation data

do not hesistate to contact the authors at [this email](mailto:ssack@kth.se) address.  
